<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">

<!--
SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.

SPDX-License-Identifier: LGPL-3.0-or-later
-->

<context>
    <name>DAboutDialog</name>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="190"/>
        <source>Acknowledgements</source>
        <translation>Erkenningen</translation>
    </message>
    <message>
        <location filename="../widgets/dapplication.cpp" line="1528"/>
        <source>Version: %1</source>
        <translation>Versie: %1</translation>
    </message>
    <message>
        <location filename="../widgets/dapplication.cpp" line="1532"/>
        <source>%1 is released under %2</source>
        <translation>%1 is uitgebracht onder de %2</translation>
    </message>
</context>
<context>
    <name>DCrumbEdit</name>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="840"/>
        <source>Black</source>
        <translation>Zwart</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="843"/>
        <source>White</source>
        <translation>Wit</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="846"/>
        <source>Dark Gray</source>
        <translation>Donkergrijs</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="849"/>
        <source>Gray</source>
        <translation>Grijs</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="852"/>
        <source>Light Gray</source>
        <translation>Lichtgrijs</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="855"/>
        <source>Red</source>
        <translation>Rood</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="858"/>
        <source>Green</source>
        <translation>Groen</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="861"/>
        <source>Blue</source>
        <translation>Blauw</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="864"/>
        <source>Cyan</source>
        <translation>Groenblauw</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="867"/>
        <source>Magenta</source>
        <translation>Magenta</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="870"/>
        <source>Yellow</source>
        <translation>Geel</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="873"/>
        <source>Dark Red</source>
        <translation>Donkerrood</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="876"/>
        <source>Dark Green</source>
        <translation>Donkergroen</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="879"/>
        <source>Dark Blue</source>
        <translation>Donkerblauw</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="882"/>
        <source>Dark Cyan</source>
        <translation>Donkergroenblauw</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="885"/>
        <source>Dark Magenta</source>
        <translation>Donkermagenta</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="888"/>
        <source>Dark Yellow</source>
        <translation>Donkergeel</translation>
    </message>
</context>
<context>
    <name>DInputDialog</name>
    <message>
        <location filename="../widgets/dinputdialog.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../widgets/dinputdialog.cpp" line="43"/>
        <source>Confirm</source>
        <translation>Oké</translation>
    </message>
</context>
<context>
    <name>DKeySequenceEdit</name>
    <message>
        <location filename="../widgets/dkeysequenceedit.cpp" line="86"/>
        <source>Enter a new shortcut</source>
        <translation>Druk op een nieuwe sneltoets</translation>
    </message>
</context>
<context>
    <name>DLineEdit</name>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="562"/>
        <source>Stop reading</source>
        <translation>Stoppen met voorlezen</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="564"/>
        <source>Text to Speech</source>
        <translation>Tekst-naar-spraak</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="587"/>
        <source>Translate</source>
        <translation>Vertalen</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="609"/>
        <source>Speech To Text</source>
        <translation>Spraak-naar-tekst</translation>
    </message>
</context>
<context>
    <name>DPrintPreviewDialogPrivate</name>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="235"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1181"/>
        <source>Advanced</source>
        <translation>Geavanceerd</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="258"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="259"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1597"/>
        <source>Print</source>
        <comment>button</comment>
        <translation>Afdrukken</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="275"/>
        <source>Basic</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="290"/>
        <source>Printer</source>
        <translation>Printer</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="304"/>
        <source>Copies</source>
        <translation>Aantal kopieën</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="324"/>
        <source>Page range</source>
        <translation>Paginabereik</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="326"/>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="327"/>
        <source>Current page</source>
        <translation>Huidige pagina</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="328"/>
        <source>Select pages</source>
        <translation>Bepaalde pagina&apos;s</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="343"/>
        <source>Orientation</source>
        <translation>Oriëntatie</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="367"/>
        <source>Portrait</source>
        <translation>Verticaal</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="377"/>
        <source>Landscape</source>
        <translation>Horizontaal</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="405"/>
        <source>Pages</source>
        <translation>Pagina&apos;s</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="415"/>
        <source>Color mode</source>
        <translation>Kleurmodus</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="417"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1554"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1621"/>
        <source>Color</source>
        <translation>Kleur</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="417"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1606"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1621"/>
        <source>Grayscale</source>
        <translation>Grijswaarden</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="428"/>
        <source>Margins</source>
        <translation>Marges</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="430"/>
        <source>Narrow (mm)</source>
        <translation>Smal (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="430"/>
        <source>Normal (mm)</source>
        <translation>Normaal (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="430"/>
        <source>Moderate (mm)</source>
        <translation>Redelijk smal (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="430"/>
        <source>Customize (mm)</source>
        <translation>Aangepast (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="436"/>
        <source>Top</source>
        <translation>Bovenkant</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="439"/>
        <source>Left</source>
        <translation>Linkerkant</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="442"/>
        <source>Bottom</source>
        <translation>Onderkant</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="445"/>
        <source>Right</source>
        <translation>Rechterkant</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="490"/>
        <source>Scaling</source>
        <translation>Grootte</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="504"/>
        <source>Actual size</source>
        <translation>Ware grootte</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="513"/>
        <source>Scale</source>
        <translation>Schaal</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="544"/>
        <source>Paper</source>
        <translation>Papier</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="554"/>
        <source>Paper size</source>
        <translation>Papiergrootte</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="567"/>
        <source>Print Layout</source>
        <translation>Afdrukindeling</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="578"/>
        <source>Duplex</source>
        <translation>Duplex</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="591"/>
        <source>N-up printing</source>
        <translation>N-omhoog afdrukken</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="593"/>
        <source>2 pages/sheet, 1×2</source>
        <translation>2 pagina&apos;s/vellen, 1x2</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="593"/>
        <source>4 pages/sheet, 2×2</source>
        <translation>4 pagina&apos;s/vellen, 2x2</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="593"/>
        <source>6 pages/sheet, 2×3</source>
        <translation>6 pagina&apos;s/vellen, 2x3</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="593"/>
        <source>9 pages/sheet, 3×3</source>
        <translation>9 pagina&apos;s/vellen, 3x3</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="593"/>
        <source>16 pages/sheet, 4×4</source>
        <translation>16 pagina&apos;s/vellen, 4x4</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="602"/>
        <source>Layout direction</source>
        <translation>Indelingsrichting</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="647"/>
        <source>Page Order</source>
        <translation>Paginavolgorde</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="658"/>
        <source>Collate pages</source>
        <translation>Pagina&apos;s bundelen</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="664"/>
        <source>Print pages in order</source>
        <translation>Pagina&apos;s op volgorde afdrukken</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="666"/>
        <source>Front to back</source>
        <translation>Voor-naar-achter</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="666"/>
        <source>Back to front</source>
        <translation>Achter-naar-voor</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="690"/>
        <source>Watermark</source>
        <translation>Watermerk</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="701"/>
        <source>Add watermark</source>
        <translation>Watermerk toevoegen</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="743"/>
        <source>Text watermark</source>
        <translation>Tekstwatermerk</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="745"/>
        <source>Confidential</source>
        <translation>Vertrouwelijk</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="745"/>
        <source>Draft</source>
        <translation>Concept</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="745"/>
        <source>Sample</source>
        <translation>Voorbeeld</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="745"/>
        <source>Custom</source>
        <translation>Aangepast</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="753"/>
        <source>Input your text</source>
        <translation>Voer hier tekst in</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="776"/>
        <source>Picture watermark</source>
        <translation>Afbeeldingswatermerk</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="797"/>
        <source>Layout</source>
        <translation>Indeling</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="799"/>
        <source>Tile</source>
        <translation>Tegels</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="799"/>
        <source>Center</source>
        <translation>Centreren</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="810"/>
        <source>Angle</source>
        <translation>Hoek</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="826"/>
        <source>Size</source>
        <translation>Afmetingen</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="847"/>
        <source>Transparency</source>
        <translation>Doorzichtigheid</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="904"/>
        <source>Print to PDF</source>
        <translation>Afdrukken naar pdf</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="905"/>
        <source>Save as Image</source>
        <translation>Opslaan als afbeelding</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1177"/>
        <source>Collapse</source>
        <translation>Inklappen</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1300"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1307"/>
        <source>Flip on short edge</source>
        <translation>Omdraaien aan korte zijde</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1303"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1306"/>
        <source>Flip on long edge</source>
        <translation>Omdraaien aan lange zijde</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1397"/>
        <source>Input page numbers please</source>
        <translation>Voer de paginanummers in</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1400"/>
        <source>Maximum page number reached</source>
        <translation>Het maximale pagina-aantal is bereikt</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1403"/>
        <source>Input English comma please</source>
        <translation>Voer een Europese komma in</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1406"/>
        <source>Input page numbers like this: 1,3,5-7,11-15,18,21</source>
        <translation>Voer de paginanummers als volgt in: 1,3,5-7,11-15,18,21</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1559"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Opslaan</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2174"/>
        <source>*.pdf</source>
        <translation>*.pdf</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1673"/>
        <source>For example, 1,3,5-7,11-15,18,21</source>
        <translation>Voorbeeld: 1,3,5-7,11-15,18,21</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2174"/>
        <source>Save as PDF</source>
        <translation>Opslaan als pdf-bestand</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2213"/>
        <source>Save as image</source>
        <translation>Opslaan als afbeelding</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2215"/>
        <source>Images</source>
        <translation>Afbeeldingen</translation>
    </message>
</context>
<context>
    <name>DPrintPreviewWidget</name>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1619"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1622"/>
        <source>Confidential</source>
        <translation>Vertrouwelijk</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1637"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1640"/>
        <source>Draft</source>
        <translation>Concept</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1655"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1658"/>
        <source>Sample</source>
        <translation>Voorbeeld</translation>
    </message>
</context>
<context>
    <name>DSearchEdit</name>
    <message>
        <location filename="../widgets/dsearchedit.cpp" line="297"/>
        <source>Search</source>
        <translation>Zoeken</translation>
    </message>
</context>
<context>
    <name>DSettingsDialog</name>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="78"/>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="79"/>
        <source>Replace</source>
        <translation>Vervangen</translation>
    </message>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="81"/>
        <source>This shortcut conflicts with %1, click on Add to make this shortcut effective immediately</source>
        <translation>Deze sneltoets is al in gebruik voor ‘%1’. Klik op ‘Toevoegen’ om déze sneltoets toe te wijzen.</translation>
    </message>
</context>
<context>
    <name>DShortcutEdit</name>
    <message>
        <location filename="../widgets/dshortcutedit.cpp" line="31"/>
        <source>Please input a new shortcut</source>
        <translation>Druk op een nieuwe sneltoets</translation>
    </message>
    <message>
        <location filename="../widgets/dshortcutedit.cpp" line="102"/>
        <source>None</source>
        <translation>Geen</translation>
    </message>
</context>
<context>
    <name>DSplitScreenWidget</name>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="215"/>
        <source>Unmaximize</source>
        <translation>De-maximaliseren</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="218"/>
        <source>Maximize</source>
        <translation>Maximaliseren</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="258"/>
        <source>Tile window to left of screen</source>
        <translation>Venster tegelen aan linkerkant</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="259"/>
        <source>Tile window to right of screen</source>
        <translation>Venster tegelen aan rechterkant</translation>
    </message>
</context>
<context>
    <name>DTextEdit</name>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="185"/>
        <source>Stop reading</source>
        <translation>Stoppen met voorlezen</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="187"/>
        <source>Text to Speech</source>
        <translation>Tekst-naar-spraak</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="210"/>
        <source>Translate</source>
        <translation>Vertalen</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="232"/>
        <source>Speech To Text</source>
        <translation>Spraak-naar-tekst</translation>
    </message>
</context>
<context>
    <name>PickColorWidget</name>
    <message>
        <location filename="../widgets/dprintpickcolorwidget.cpp" line="110"/>
        <source>Color</source>
        <translation>Kleur</translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="536"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopiëren</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="539"/>
        <source>Cu&amp;t</source>
        <translation>Kni&amp;ppen</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="545"/>
        <source>Select All</source>
        <translation>Alles selecteren</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../widgets/dsimplelistview.cpp" line="1366"/>
        <source>No search result</source>
        <translation>Geen zoekresultaten</translation>
    </message>
    <message>
        <location filename="../widgets/private/settings/content.cpp" line="340"/>
        <source>Restore Defaults</source>
        <translation>Standaardwaarden herstellen</translation>
    </message>
</context>
<context>
    <name>QWidgetTextControl</name>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="177"/>
        <source>Select All</source>
        <translation>Alles selecteren</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../widgets/private/settings/shortcutedit.cpp" line="117"/>
        <source>Please enter a new shortcut</source>
        <translation>Druk op een nieuwe sneltoets</translation>
    </message>
</context>
<context>
    <name>TitleBarMenu</name>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="770"/>
        <source>Theme</source>
        <translation>Thema</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="772"/>
        <source>Light Theme</source>
        <translation>Licht thema</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="773"/>
        <source>Dark Theme</source>
        <translation>Donker thema</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="774"/>
        <source>System Theme</source>
        <translation>Systeemthema</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="799"/>
        <source>Help</source>
        <translation>Hulp</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="807"/>
        <source>Feedback</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="814"/>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="821"/>
        <source>Exit</source>
        <translation>Afsluiten</translation>
    </message>
</context>
</TS>